User Interface Globalization — CKEditor Sample

# CKEditor Samples » User Interface Languages

This sample shows how to automatically replace `<textarea>` elements with a CKEditor instance with an option to change the language of its user interface.

It pulls the language list from CKEditor `_languages.js` file that contains the list of supported languages and creates a drop-down list that lets the user change the UI language.

By default, CKEditor automatically localizes the editor to the language of the user. The UI language can be controlled with two configuration options: `language` and `defaultLanguage`. The `defaultLanguage` setting specifies the default CKEditor language to be used when a localization suitable for user's settings is not available.

To specify the user interface language that will be used no matter what language is specified in user's browser or operating system, set the `language` property:

    CKEDITOR.replace( 'textarea_id', {
    	// Load the German interface.
    	language: 'de'
    });

Note that `textarea_id` in the code above is the `id` attribute of the `<textarea>` element to be replaced.

Available languages ( languages!):
(You may see strange characters if your system does not support the selected language)

<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>